@@ -39,8 +39,8 @@ setMethod("as.magpie",
     x <- array(x[magclassdata$half_deg$lpj_index, , , ], dim = c(dim(x)[1:2], dim(x)[3] * dim(x)[4]))
     # convert to previous default standard 59199 cells half degree resolution
     dimnames(x) <- list(paste(magclassdata$half_deg$region, 1:59199, sep = "."),
-      xdimnames[[2]],
-      paste(rep(xdimnames[[3]], xdim[4]), rep(xdimnames[[4]], each = xdim[3]), sep = "."))
+                        xdimnames[[2]],
+                        paste(rep(xdimnames[[3]], xdim[4]), rep(xdimnames[[4]], each = xdim[3]), sep = "."))
     out <- new("magpie", x)
     return(out)
   }
@@ -63,8 +63,7 @@ setMethod("as.magpie",
             }
             out <- new("magpie", y)
             return(out)
-          }
-)
+          })
 
 setMethod("as.magpie", # nolint
   signature(x = "array"),
@@ -115,9 +114,11 @@ setMethod("as.magpie", # nolint
     # Write warning when any type (except type "nothing") is found more than once
     nOccurrence <- lapply(d, length) > 1
     nOccurrence <- nOccurrence[names(nOccurrence) != "nothing"]
-    if (any(nOccurrence) == TRUE) warning("No clear mapping of dimensions to dimension types. First detected ",
-      "possibility is used! Please use arguments temporal and spatial to specify",
-      " which dimensions are what!")
+    if (any(nOccurrence) == TRUE) {
+      warning("No clear mapping of dimensions to dimension types. First detected ",
+              "possibility is used! Please use arguments temporal and spatial to specify",
+              " which dimensions are what!")
+    }
     for (i in which(nOccurrence)) {
       d[[i]] <- d[[i]][1]
     }
@@ -199,18 +200,16 @@ setMethod("as.magpie", # nolint
 )
 
 setMethod("as.magpie",
-  signature(x = "numeric"),
-  function(x, unit = "unknown", ...) {
-    return(copy.attributes(x, as.magpie(as.array(x), ...)))
-  }
-)
+          signature(x = "numeric"),
+          function(x, unit = "unknown", ...) {
+            return(copy.attributes(x, as.magpie(as.array(x), ...)))
+          })
 
 setMethod("as.magpie",
           signature(x = "logical"),
           function(x, unit = "unknown", ...) {
             return(copy.attributes(x, as.magpie(as.array(x), ...)))
-          }
-)
+          })
 
 setMethod("as.magpie",
   signature(x = "NULL"),
@@ -244,6 +243,12 @@ setMethod("as.magpie",
       }
     }
     if (!is.null(datacol)) {
+      if (is.character(datacol)) {
+        datacol <- which(colnames(x) == datacol)
+        if (length(datacol) != 1) {
+          stop("datacol does not clearly match one column name.")
+        }
+      }
       if (datacol == 1) return(copy.attributes(x, as.magpie(as.matrix(x), ...)))
       if (datacol == dim(x)[2]) return(tidy2magpie(x, ...))
       x[[datacol - 1]] <- as.factor(x[[datacol - 1]])
@@ -271,8 +276,10 @@ setMethod("as.magpie",
 
       mandatoryColumns <- c("model", "scenario", "region", "variable", "unit", "period", "value")
       factorColumns    <- c("model", "scenario", "region", "variable", "unit")
-      isQuitte <- all(mandatoryColumns %in% names(x)) && all(vapply(x[factorColumns], is.factor, logical(1))) &&
-                  is.numeric(x$value) && (methods::is(x$period, "POSIXct") || is.integer(x$period))
+      isQuitte <- (all(mandatoryColumns %in% names(x)) &&
+                     all(vapply(x[factorColumns], is.factor, logical(1))) &&
+                     is.numeric(x$value) &&
+                     (methods::is(x$period, "POSIXct") || is.integer(x$period)))
       return(isQuitte)
     }
 
@@ -320,12 +327,23 @@ setMethod("as.magpie",
 )
 
 
-.raster2magpie <- function(x, unit = "unknown", temporal = NULL) {
+.raster2magpie <- function(x, unit = "unknown", temporal = NULL, spatial = NULL) {
+  geometry <- NULL
+  idVars <- NULL
+  crs <- NULL
   if (inherits(x, "SpatRaster")) {
     if (!requireNamespace("terra", quietly = TRUE)) stop("The package \"terra\" is required for raster conversions!")
     df <- as.data.frame(x, na.rm = TRUE, xy = TRUE)
     df$x <- sub(".", "p", df$x, fixed = TRUE)
     df$y <- sub(".", "p", df$y, fixed = TRUE)
+    idVars <- c("x", "y")
+    crs <- terra::crs(x)
+  } else if (inherits(x, "SpatVector")) {
+    if (!requireNamespace("terra", quietly = TRUE)) stop("The package \"terra\" is required for raster conversions!")
+    df <- as.data.frame(x, geom = "WKT")
+    geometry <- df$geometry
+    df$geometry <- NULL
+    crs <- terra::crs(x)
   } else {
     if (!requireNamespace("raster", quietly = TRUE)) stop("The package \"raster\" is required for raster conversions!")
     # na.rm = TRUE seems to remove all cells in which at least one layer has an NA. Hence, use na.rm = FALSE
@@ -337,28 +355,57 @@ setMethod("as.magpie",
     co <- matrix(sub(".", "p", co, fixed = TRUE), ncol = 2)
     colnames(co) <- c("x", "y")
     df <- cbind(co, df)
+    idVars <- c("x", "y")
+  }
+
+  # check for additional spatial identifiers
+  if (is.null(spatial)) {
+    # select all layers with a leading dot in its name as spatial dimension
+    spatial <- grep("^\\.", names(x), value = TRUE)
+  } else {
+    if (all(is.integer(spatial))) {
+      spatial <- names(x)[spatial]
+    }
+  }
+  names(df) <- sub("^\\.", "", names(df))
+  spatial  <- sub("^\\.", "", spatial)
+
+  idVars <- c(spatial, idVars)
+
+  if (length(idVars) == 0) {
+    df <- cbind(id = df[[1]], df)
+    idVars <- "id"
   }
 
   df <- as.data.table(df)
-  df <- melt(df, id.vars = c("x", "y"))
+  df <- melt(df, id.vars = idVars)
   variable <- as.data.table(tstrsplit(df$variable, "..", fixed = TRUE))
-  if (!is.null(temporal)) temporal <- temporal + 2
+  if (!is.null(temporal)) temporal <- temporal + length(idVars)
   if (ncol(variable) == 1) {
     if (all(grepl("^[yX][0-9]*$", variable[[1]], perl = TRUE))) {
       variable[[1]] <- sub("^X", "y", variable[[1]], perl = TRUE)
       names(variable) <- "year"
-      if (is.null(temporal)) temporal <- 3
+      if (is.null(temporal)) temporal <- length(idVars) + 1
     } else {
       names(variable) <- "data"
     }
   } else if (ncol(variable) == 2) {
     names(variable) <- c("year", "data")
-    if (is.null(temporal)) temporal <- 3
+    if (is.null(temporal)) temporal <- length(idVars) + 1
   } else {
     stop("Reserved dimension separator \"..\" occurred more than once in layer names! Cannot convert raster object")
   }
-  df <- cbind(df[, 1:2], variable, df[, 4])
-  out <- tidy2magpie(df, spatial = 1:2, temporal = temporal)
+  df <- as.data.frame(df)
+  baseDims <- which(!(colnames(df) %in% c("variable", "value")))
+  df <- cbind(df[, baseDims, drop = FALSE], variable, df[, "value", drop = FALSE])
+  out <- tidy2magpie(df, spatial = idVars, temporal = temporal)
+  if (!is.null(geometry)) {
+    names(geometry) <- getItems(out, dim = 1)
+    attr(out, "geometry") <- geometry
+  }
+  if (!is.null(crs)) {
+    attr(out, "crs") <- crs
+  }
   return(out)
 }
 
@@ -387,5 +434,10 @@ setMethod("as.magpie",
           signature(x = "SpatRaster"),
           function(x, unit = "unknown", temporal = NULL, ...) {
             return(.raster2magpie(x, unit = unit, temporal = temporal))
-          }
-)
+          })
+
+setMethod("as.magpie",
+          signature(x = "SpatVector"),
+          function(x, unit = "unknown", temporal = NULL, spatial = NULL, ...) {
+            return(.raster2magpie(x, unit = unit, temporal = temporal, spatial = spatial))
+          })
