@@ -1,26 +1,38 @@
 #' Write MAgPIE-object to file
 #'
-#' Writes a MAgPIE-3D-array (cells,years,datacolumn) to a file in one of three
-#' MAgPIE formats (standard, "magpie", "magpie zipped")
+#' Writes a magpie object to a file. The file type is determined by the filename extension.
+#' The written file can be read again using \code{\link{read.magpie}}.
 #'
-#' This function can write 13 different MAgPIE file_types. "cs2" is the new
-#' standard format for cellular data with or without header and the first
-#' columns (year,regiospatial) or only (regiospatial), "cs2b" is identical to
-#' "cs2" except that it will suppress the data name if it has only 1 element
-#' in the data dimension. "csv" is the standard format for regional
-#' data with or without header and the first columns (year,region,cellnumber)
-#' or only (region,cellnumber), "cs3" is another csv format which is
+#' This function supports writing the following file types:
+#' \itemize{
+#' \item "cs2" is the new standard format for cellular data with or without header
+#' and the first columns (year,regiospatial) or only (regiospatial)
+#' \item "cs2b" is identical to "cs2" except that it will suppress the data name
+#' if it has only 1 element in the data dimension.
+#' \item "csv" is the standard format for regional data with or without header and
+#' the first columns (year,region,cellnumber) or only (region,cellnumber)
+#' \item "cs3" is another csv format which is
 #' specifically designed for multidimensional data for usage in GAMS.
-#' All these variants are written without further specification. "rds" is
-#' a R-default format for storing R objects.
-#' "magpie" (.m) and "magpie zipped" (.mz) are new formats developed to allow a
-#' less storage intensive management of MAgPIE-data. The only difference
+#' \item "cs4" alternative multidimensional format compatible to GAMS, in contrast
+#' to cs3 it can also handle sparse data
+#' \item "csvr", "cs2r", "cs3r", "cs4r" which are the same formats as the ones
+#' previously explained with the only difference that they have a REMIND
+#' compatible format
+#' \item "cs5" a more generalized version of cs4
+#' \item "rds" is an R-default format for storing R objects
+#' \item "m" (magpie) and "mz" (magpie zipped) are new formats developed to allow
+#' a less storage intensive management of MAgPIE-data. The only difference
 #' between both formats is that .mz is gzipped whereas .m is not compressed. So
 #' .mz needs less memory, whereas .m might have a higher compatibility to other
-#' languages. "asc" is the ASCII grid format. "nc" is the netCDF format.  It
-#' can only be applied for half degree data and writes one file per year per
-#' data column. In the case that more than one year and data column is supplied
-#' several files are written with the structure filename_year_datacolumn.asc
+#' languages
+#' \item "asc" is the ASCII grid format. It can only be applied for gridded data
+#' and writes one file per year per data column. In the case that more than
+#' one year and data column is supplied several files are written with the
+#' structure filename_year_datacolumn.asc
+#' \item "tif" is the  GEOtiff format for gridded data.
+#' \item "grd" is the native raster format for gridded data.
+#' \item "nc" is the netCDF format for gridded data.
+#' }
 #'
 #' @param x a magclass object. An exception is that formats written via the raster package
 #' (currently "nc", "asc", "grd" and "tif") also accept RasterBrick objects which have
@@ -30,21 +42,11 @@
 #' to file_name and file_folder)
 #' @param file_folder folder the file should be written to (alternatively you
 #' can also specify the full path in file_name - wildcards are supported)
-#' @param file_type Format the data should be stored as. Currently the following formats
-#' are available: "rds" (default R-data format), "cs2" (cellular standard
-#' MAgPIE format), "cs2b" (cellular standard MAgPIE format with suppressed header ndata=1),
-#' "csv" (regional standard MAgPIE format), "cs3" (Format for multidimensional MAgPIE
-#' data, compatible to GAMS), "cs4" (alternative multidimensional format compatible
-#' to GAMS, in contrast to cs3 it can also handle sparse data), "cs5" (more generalized version of cs4),
-#' "csvr", "cs2r", "cs3r" and "cs4r" which are the same formats as the previous mentioned ones
-#' with the only difference that they have a REMIND compatible format, "m"
-#' (binary MAgPIE format "magpie"), "mz" (compressed binary MAgPIE format
-#' "magpie zipped"), "asc" (ASCII grid format), "nc" (netCDF format), "tif"
-#' (GEOtiff format) and "grd" (native raster format). If file_type=NULL
-#' the file ending of the file_name is used as format. If
-#' format is different to the formats mentioned standard MAgPIE format is
-#' assumed. Please be aware that the file_name is independent of the
-#' file_type you choose here, so no additional file ending will be added!
+#' @param file_type Format the data should be stored as. If file_type=NULL
+#' the file ending of the file_name is used as format. See detailed
+#' description for a list of available file types. Please be aware that the
+#' file_name is independent of the file_type you choose here, so no additional
+#' file ending will be added!
 #' @param append Decides whether an existing file should be overwritten (FALSE)
 #' or the data should be added to it (TRUE). Append = TRUE only works if the
 #' existing data can be combined with the new data using the mbind function
@@ -59,7 +61,7 @@
 #' full access for user, read access for group and no acess for anybody else).
 #' Set to NULL system defaults will be used. Access codes are identical to the
 #' codes used in unix function chmod.
-#' @param zname Time variable for the writeRaster function
+#' @param zname name of the time variable for raster files like nc, asc, grd and tif
 #' @param ... additional arguments passed to specific write functions
 #' @note
 #'
@@ -83,17 +85,20 @@
 #' [ sets | Set names with \\n as delimiter | character | 1*nchar_sets Byte] \cr
 #' [ metadata | serialized metadata information (currently not in use) | bytes | 1*nbyte_metadata Byte] \cr
 #'
-#' @author Jan Philipp Dietrich, Stephen Bi, Florian Humpenoeder
+#' @author Jan Philipp Dietrich, Stephen Bi, Florian Humpenoeder, Pascal Sauer
 #' @seealso \code{"\linkS4class{magpie}"},
 #' \code{\link{read.magpie}},\code{\link{mbind}}
 #' @examples
-#'
-#' # a <- read.magpie("lpj_yield_ir.csv")
-#' # write.magpie(a,"lpj_yield_ir.mz")
-#' @importFrom utils write.csv write.table
+#' pop <- maxample("pop")
+#' path <- tempfile(fileext = ".mz")
+#' write.magpie(pop, path)
+#' pop2 <- read.magpie(path)
 #' @export
-write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, append = FALSE, comment = NULL, # nolint
-                         comment.char = "*", mode = NULL, zname = "Time",...) {       # nolint
+write.magpie <- function(x, # nolint: object_name_linter, cyclocomp_linter.
+                         file_name, file_folder = "", file_type = NULL, # nolint: object_name_linter.
+                         append = FALSE, comment = NULL,
+                         comment.char = "*", # nolint: object_name_linter.
+                         mode = NULL, zname = "time", ...) {
   umask <- Sys.umask()
   if (!is.null(mode)) {
     umaskMode <- as.character(777 - as.integer(mode))
@@ -107,7 +112,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
 
     # if file-type is not mentioned file-ending is used as file-type
     if (is.null(file_type)) {
-      file_type <- tail(strsplit(file_name, "\\.")[[1]], 1) # nolint
+      file_type <- tail(strsplit(file_name, "\\.")[[1]], 1) # nolint: object_name_linter.
     }
     if (inherits(x, "RasterBrick") && !(file_type %in% c("nc", "asc", "grd", "tif"))) {
       stop("RasterBrick format is only allowed for file types: nc, asc, grd and tif")
@@ -115,7 +120,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
     if (!file_folder == "") {
       filePath <- paste(file_folder, file_name, sep = "/")
     } else {
-      filePath <- file_name # nolint
+      filePath <- file_name
     }
 
     # look for comment/additional information
@@ -190,8 +195,10 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
         years <- sort(unique(unlist(lapply(tmp, function(x) x[1]))))
         varname <- sort(unique(unlist(lapply(tmp, function(x) x[2]))))
         zunit <- ifelse(all(isYear(years)), "years", "")
-        if (length(varname) != 1) stop("Currently no support for multiple variables for file type \"", file_type,
-                                "\". Please store each variable separately.")
+        if (length(varname) != 1) {
+          stop("Currently no support for multiple variables for file type \"", file_type,
+               "\". Please store each variable separately.")
+        }
       }
       if (file_type == "asc") {
         if (dim(x)[3] != 1) stop("asc does not support multiple year layers. Please choose just one!")
@@ -201,56 +208,27 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
       raster::writeRaster(x, filename = filePath, format = format[file_type], overwrite = TRUE,
                           zname = zname, zunit = zunit, varname = varname, ...)
     } else if (file_type == "nc") {
+      if (!requireNamespace("ncdf4", quietly = TRUE) || !requireNamespace("terra", quietly = TRUE)) {
+        stop("The packages \"ncdf4\" and \"terra\" are required!")
+      }
+      if (is.null(getItems(x, 3))) {
+        getItems(x, 3) <- "Variable"
+      }
+      spatRasterDataset <- as.SpatRasterDataset(x)
 
-      if (!requireNamespace("ncdf4", quietly = TRUE) || !requireNamespace("raster", quietly = TRUE)) {
-        stop("The packages \"ncdf4\" and \"raster\" are required!")
+      if (zname != "time") {
+        warning("zname != 'time' is discouraged, as terra will not recognize it as time dimension")
       }
-      .sub <- function(rx, name) {
-        layer <- sub("^.*\\.\\.", "", names(rx))
-        if (length(unique(layer)) == 1) return(rx)
-        return(rx[[which(layer == name)]])
-      }
-      if (is.magpie(x)) {
-        varnames <- getItems(x, dim = 3)
-        zunit <- ifelse(all(isYear(getYears(x))), "years", "")
-        years <- getYears(x, as.integer = TRUE)
-        x <- as.RasterBrick(x)
-      } else if (inherits(x, "RasterBrick")) {
-        tmp <- names(x)
-        tmp <- strsplit(tmp, "\\..")
-        years <- sort(unique(unlist(lapply(tmp, function(x) x[1]))))
-        varnames <- sort(unique(unlist(lapply(tmp, function(x) x[2]))))
-        zunit <- ifelse(all(isYear(years)), "years", "")
-        years <- as.numeric(gsub("y", "", years))
-      }
-      if (is.null(varnames)) varnames <- "Variable"
-      if (is.null(comment)) {
-       unit <- "not specified"
-      } else {
-        indicators <- sub(":.*$", "", comment)
-        units <- sub("^.*: ", "", comment)
-        if (any(grepl("unit", indicators))) {
-          unit <- units[grep("unit", indicators)]
-        } else {
-          unit <- "not specified"
-        }
-      }
-      # raster is using partial matching resulting in a warning if warnPartialMatchDollar is set
+      # terra::writeCDF does not set the "axis" attribute for the time dimension, which triggers a warning
       suppressSpecificWarnings({
-        raster::writeRaster(.sub(x, varnames[1]), filename = filePath, format = "CDF", overwrite = TRUE,
-                            compression = 9, zname = zname, zunit = zunit, varname = varnames[1], varunit = unit, ...)
-      }, "partial match of 'group' to 'groups'", fixed = TRUE)
+        terra::writeCDF(spatRasterDataset, filePath, overwrite = TRUE, zname = zname, ...)
+      }, paste0("GDAL Message 1: dimension #0 (", zname, ") is not a Time or Vertical dimension."), fixed = TRUE)
+
+      # set the "axis" attribute to "T" for the time dimension to prevent further warnings when reading the file
       nc <- ncdf4::nc_open(filePath, write = TRUE)
-      if (zunit == "years") {
-        try(ncdf4::ncvar_put(nc, zname, years), silent = TRUE)
-      }
-      if (length(varnames) > 1) {
-        for (i in varnames[-1]) {
-          suppressSpecificWarnings({
-            nc <- ncdf4::ncvar_add(nc, ncdf4::ncvar_def(i, unit, nc$dim, compression = 9))
-          }, "partial match of 'group' to 'groups'", fixed = TRUE)
-          ncdf4::ncvar_put(nc, i, aperm(as.array(.sub(x, i)), c(2, 1, 3)))
-        }
+      # nc will not have time dim when x had no time dimension
+      if (zname %in% names(nc$dim)) {
+        ncdf4::ncatt_put(nc, zname, "axis", "T")
       }
       ncdf4::nc_close(nc)
     } else if (file_type == "rds") {
@@ -286,7 +264,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
       dimnames(x)[[2]] <- c(gsub("[^,]*(,|$)", "dummy\\1", x[1, 1]), header)
       zz <- file(filePath, open = "w")
       if (any(comment != "")) writeLines(paste(comment.char, comment, sep = ""), zz)
-      write.csv(x, file = zz, quote = FALSE, row.names = FALSE)
+      utils::write.csv(x, file = zz, quote = FALSE, row.names = FALSE)
       close(zz)
       Sys.chmod(filePath, mode)
     } else if (file_type == "cs4" || file_type == "cs4r") {
@@ -307,7 +285,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
       }
       zz <- file(filePath, open = "w")
       if (any(comment != "")) writeLines(paste(comment.char, comment, sep = ""), zz)
-      write.table(output, file = zz, quote = FALSE, row.names = FALSE, col.names = FALSE, sep = ",")
+      utils::write.table(output, file = zz, quote = FALSE, row.names = FALSE, col.names = FALSE, sep = ",")
       close(zz)
       Sys.chmod(filePath, mode)
     } else if (file_type == "cs5") {
@@ -324,7 +302,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
       zz <- file(filePath, open = "w")
       if (any(comment != "")) writeLines(paste(comment.char, comment, sep = ""), zz)
       writeLines(.formatMeta(attributes(output)[c("names", "dimtype")], comment.char), zz)
-      write.table(output, file = zz, quote = FALSE, row.names = FALSE, col.names = FALSE, sep = ",")
+      utils::write.table(output, file = zz, quote = FALSE, row.names = FALSE, col.names = FALSE, sep = ",")
       close(zz)
 
     } else {
@@ -370,7 +348,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
         if (header && printRegions) dimnames(output)[[2]][1] <- "dummy"
         zz <- file(filePath, open = "w")
         if (any(comment != "")) writeLines(paste(comment.char, comment, sep = ""), zz)
-        write.table(output, zz, sep = ",", col.names = header, row.names = FALSE, quote = FALSE)
+        utils::write.table(output, zz, sep = ",", col.names = header, row.names = FALSE, quote = FALSE)
         close(zz)
         Sys.chmod(filePath, mode)
       } else {
@@ -399,7 +377,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
         }
         zz <- file(filePath, open = "w")
         if (any(comment != "")) writeLines(paste0(comment.char, comment, sep = ""), zz)
-        write.table(output, zz, sep = ",", col.names = header, row.names = FALSE, quote = FALSE)
+        utils::write.table(output, zz, sep = ",", col.names = header, row.names = FALSE, quote = FALSE)
         close(zz)
         Sys.chmod(filePath, mode)
       }
@@ -407,5 +385,7 @@ write.magpie <- function(x, file_name, file_folder = "", file_type = NULL, appen
   } else {
     stop("Input is not in MAgPIE-format!")
   }
-  if (!is.null(mode)) Sys.umask(umask)
+  if (!is.null(mode)) {
+    Sys.umask(umask)
+  }
 }
